from setuptools import setup

setup(name='gb_distributions_plots',
      version='1.0',
      description='Gaussian and Binomial distributions',
      packages=['gb_distributions_plots'],
      author = 'Kaustubh Katkar',
      zip_safe=False)
